;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "vertico" "2.8"
  "VERTical Interactive COmpletion."
  '((emacs  "29.1")
    (compat "30"))
  :url "https://github.com/minad/vertico"
  :commit "0b96e8f169653cba6530da1ab0a1c28ffa44b180"
  :revdesc "2.8-0-g0b96e8f16965"
  :keywords '("convenience" "files" "matching" "completion")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
